# `Meuse`

The *meuse* dataset is a part of `sp` (`R`) package which is presented in:

> Pebesma, Edzer. (2009). The meuse data set: a tutorial for the gstat R package. URL: https://cran.r-project.org/web/packages/gstat/vignettes/gstat.pdf